DataDomeDio class

Constructors

DataDomeDio()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

lastCookieValue ↔ String
getter/setter pair

Static Methods

getCookie() → Future<String>
Returns the DataDome cookie. The returned value should be a string representing the cookie with the datadome name and its value. Example: "datadome=xxxx"
getCookieDomain() → String
Retrieves the domain from the stored cookie.
parseCookieValue(String cookie) → String
Extracts the value of a cookie.
removeCookie() → void
Removes the stored DataDome cookie.
sendMobileSignals() → Future<bool>
storeCookie(String cookie) → Future<Null>
Store DataDome cookie. The new value should be a string representing the cookie with its value and its attributes. Example: "datadome=xxxx; Max-Age=31536000; Domain=.yourdomain.com; Path=/; Secure; SameSite=Lax"