DataDomeLogger class

A logger utility for DataDome integration.

Logs messages to the console based on the current logLevel. Use setLogLevel to control the verbosity of the logs.

Constructors

DataDomeLogger()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

logLevel ↔ int
getter/setter pair

Static Methods

error(String message) → dynamic
Logs an error message if the logLevel is LogLevel.error or lower.
info(String message) → dynamic
Logs an informational message if the logLevel is LogLevel.info or lower.
setLogLevel(int level) → dynamic
Sets the logging level to control log verbosity.
warning(String message) → dynamic
Logs a warning message if the logLevel is LogLevel.warning or lower.