HtmlResponsePage class

A ResponsePage representing a blocked response with challenge HTML.

Inheritance

Constructors

HtmlResponsePage(dynamic type, String html, Uri baseUrl)
Constructs a HtmlResponsePage with the provided type, html content, and baseUrl.

Properties

baseUrl → Uri
final
hashCode → int
The hash code for this object.
no setterinherited
html → String
final
options ↔ ResponsePageOptions?
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type ↔ ResponsePageType
getter/setter pairinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited