UrlResponsePage class

A ResponsePage representing a blocked response with challenge URL.

Inheritance

Constructors

UrlResponsePage(dynamic xddb, String url)
Constructs a UrlResponsePage with the provided xddb value and url.

Properties

hashCode → int
The hash code for this object.
no setterinherited
options ↔ ResponsePageOptions?
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type ↔ ResponsePageType
getter/setter pairinherited
url → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited