EventData class

Constructors

EventData(int id, String message, String source)

Properties

date → int
final
hashCode → int
The hash code for this object.
no setterinherited
id → int
final
message → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
source → String
final

Methods

customJsonString() → String
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited