Events enum

Inheritance
Available extensions

Values

NULL_CONTEXT → const Events
RESPONSE_VALIDATION → const Events
CAPTCHA_SUCCESS → const Events
CAPTCHA_PAGE_DISPLAY → const Events
VISIBLE_DEVICE_CHECK_DISPLAY → const Events
VISIBLE_DEVICE_CHECK_SUCCESS → const Events
INVISIBLE_DEVICE_CHECK_DISPLAY → const Events
INVISIBLE_DEVICE_CHECK_SUCCESS → const Events
HARD_BLOCK_PAGE_DISPLAY → const Events
TOUCH_DOWN → const Events
TOUCH_UP → const Events
TOUCH_MOVE → const Events
UNKNOWN_TOUCH_EVENT → const Events

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
nameValue → String

Available on Events, provided by the EventValue extension

no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<Events>
A constant List of the values in this enum, in order of their declaration.