EventTracker class

Constructors

EventTracker()
factory

Properties

events ↔ List<EventData>
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
isSendingTrackingData ↔ bool
getter/setter pair
lastTrackRequest ↔ int
getter/setter pair
minimumEventThreshold → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
setDeviceData ← Map<String, dynamic>
no getter
trackRequestInterval → int
final

Methods

addEvent(EventData event) → void
androidDeviceInfos(AndroidDeviceInfo build) → Map<String, dynamic>
getAppVersion() → Future<String>
initPlatformState() → Future<Map<String, dynamic>>
iosDeviceInfos(IosDeviceInfo data) → Map<String, dynamic>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sendEventPayload() → Future<Null>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

deviceInfoPlugin → DeviceInfoPlugin
final
sharedInstance → EventTracker
final
sourceSdk → String
final

Static Methods

eventPositionTemplate(double x, double y) → String